@@ -8,7 +8,6 @@
 
 import torchplus
 import torch
-from torch._C import _disabled_torch_function_impl
 from collections import OrderedDict
 
 class Parameter(torchplus.Tensor):
@@ -54,5 +53,3 @@ class Parameter(torchplus.Tensor):
             torch._utils._rebuild_parameter,
             (self.data, self.requires_grad, OrderedDict())
         )
-
-    __torch_function__ = _disabled_torch_function_impl
